@@ -36,7 +36,7 @@
 #include <QDir>
 
 using namespace KDevelop;
-typedef SourceFileTemplate::ConfigOption ConfigOption;
+using ConfigOption = SourceFileTemplate::ConfigOption;
 
 class KDevelop::SourceFileTemplatePrivate
 {
@@ -45,11 +45,11 @@ public:
     QString descriptionFileName;
     QStringList searchLocations;
 
-    ConfigOption readEntry(const QDomElement& element, TemplateRenderer* renderer);
+    ConfigOption readEntry(const QDomElement& element, TemplateRenderer* renderer) const;
 };
 
 ConfigOption SourceFileTemplatePrivate::readEntry(const QDomElement& element,
-                                                  TemplateRenderer* renderer)
+                                                  TemplateRenderer* renderer) const
 {
     ConfigOption entry;
 
@@ -57,36 +57,23 @@ ConfigOption SourceFileTemplatePrivate::readEntry(const QDomElement& element,
     entry.type = element.attribute(QStringLiteral("type"), QStringLiteral("String"));
 
     bool isDefaultValueSet = false;
-    for (QDomElement e = element.firstChildElement(); !e.isNull(); e = e.nextSiblingElement())
-    {
+    for (QDomElement e = element.firstChildElement(); !e.isNull(); e = e.nextSiblingElement()) {
         QString tag = e.tagName();
 
-        if (tag == QLatin1String("label"))
-        {
+        if (tag == QLatin1String("label")) {
             entry.label = e.text();
-        }
-        else if (tag == QLatin1String("tooltip"))
-        {
+        } else if (tag == QLatin1String("tooltip")) {
             entry.label = e.text();
-        }
-        else if (tag == QLatin1String("whatsthis"))
-        {
+        } else if (tag == QLatin1String("whatsthis")) {
             entry.label = e.text();
-        }
-        else if ( tag == QLatin1String("min") )
-        {
+        } else if (tag == QLatin1String("min")) {
             entry.minValue = e.text();
-        }
-        else if ( tag == QLatin1String("max") )
-        {
+        } else if (tag == QLatin1String("max")) {
             entry.maxValue = e.text();
-        }
-        else if ( tag == QLatin1String("default") )
-        {
+        } else if (tag == QLatin1String("default")) {
             entry.value = renderer->render(e.text(), entry.name);
             isDefaultValueSet = true;
-        }
-        else if (tag == QLatin1String("choices")) {
+        } else if (tag == QLatin1String("choices")) {
             QStringList values;
             QDomNodeList choices = element.elementsByTagName(QStringLiteral("choice"));
             values.reserve(choices.size());
@@ -94,6 +81,7 @@ ConfigOption SourceFileTemplatePrivate::readEntry(const QDomElement& element,
                 QDomElement choiceElement = choices.at(j).toElement();
                 values << choiceElement.attribute(QStringLiteral("name"));
             }
+
             Q_ASSERT(!values.isEmpty());
             if (values.isEmpty()) {
                 qCWarning(LANGUAGE) << "Entry " << entry.name << "has an enum without any choices";
@@ -120,55 +108,66 @@ ConfigOption SourceFileTemplatePrivate::readEntry(const QDomElement& element,
     return entry;
 }
 
-
 SourceFileTemplate::SourceFileTemplate (const QString& templateDescription)
-: d(new KDevelop::SourceFileTemplatePrivate)
+    : d_ptr(new KDevelop::SourceFileTemplatePrivate)
 {
+    Q_D(SourceFileTemplate);
+
     d->archive = nullptr;
     setTemplateDescription(templateDescription);
 }
 
 SourceFileTemplate::SourceFileTemplate()
-: d(new KDevelop::SourceFileTemplatePrivate)
+    : d_ptr(new KDevelop::SourceFileTemplatePrivate)
 {
+    Q_D(SourceFileTemplate);
+
     d->archive = nullptr;
 }
 
 SourceFileTemplate::SourceFileTemplate (const SourceFileTemplate& other)
-: d(new KDevelop::SourceFileTemplatePrivate)
+    : d_ptr(new KDevelop::SourceFileTemplatePrivate)
 {
+    Q_D(SourceFileTemplate);
+
     d->archive = nullptr;
     *this = other;
 }
 
 SourceFileTemplate::~SourceFileTemplate()
 {
+    Q_D(SourceFileTemplate);
+
     delete d->archive;
 }
 
 SourceFileTemplate& SourceFileTemplate::operator=(const SourceFileTemplate& other)
 {
-    if (other.d == d) {
+    Q_D(SourceFileTemplate);
+
+    if (other.d_ptr == d_ptr) {
         return *this;
     }
 
     delete d->archive;
-    if (other.d->archive) {
-        if (other.d->archive->fileName().endsWith(QLatin1String(".zip"))) {
-            d->archive = new KZip(other.d->archive->fileName());
+    if (other.d_ptr->archive) {
+        if (other.d_ptr->archive->fileName().endsWith(QLatin1String(".zip"))) {
+            d->archive = new KZip(other.d_ptr->archive->fileName());
         } else {
-            d->archive = new KTar(other.d->archive->fileName());
+            d->archive = new KTar(other.d_ptr->archive->fileName());
         }
         d->archive->open(QIODevice::ReadOnly);
     } else {
         d->archive = nullptr;
     }
-    d->descriptionFileName = other.d->descriptionFileName;
+    d->descriptionFileName = other.d_ptr->descriptionFileName;
     return *this;
 }
 
 void SourceFileTemplate::setTemplateDescription(const QString& templateDescription)
 {
+    Q_D(SourceFileTemplate);
+
     delete d->archive;
 
     d->descriptionFileName = templateDescription;
@@ -176,10 +175,13 @@ void SourceFileTemplate::setTemplateDescription(const QString& templateDescripti
 
     const QString templateBaseName = QFileInfo(templateDescription).baseName();
 
-    d->searchLocations.append(QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, QStringLiteral("/kdevfiletemplates/templates/"), QStandardPaths::LocateDirectory));
+    d->searchLocations.append(QStandardPaths::locateAll(QStandardPaths::GenericDataLocation,
+                                                        QStringLiteral("/kdevfiletemplates/templates/"),
+                                                        QStandardPaths::LocateDirectory));
 
-    foreach(const QString& dir, d->searchLocations) {
-        foreach(const auto& entry, QDir(dir).entryInfoList(QDir::Files)) {
+    for (const QString& dir : qAsConst(d->searchLocations)) {
+        const auto fileEntries = QDir(dir).entryInfoList(QDir::Files);
+        for (const auto& entry : fileEntries) {
             if (entry.baseName() == templateBaseName) {
                 archiveFileName = entry.absoluteFilePath();
                 qCDebug(LANGUAGE) << "Found template archive" << archiveFileName;
@@ -189,7 +191,8 @@ void SourceFileTemplate::setTemplateDescription(const QString& templateDescripti
     }
 
     if (archiveFileName.isEmpty() || !QFileInfo::exists(archiveFileName)) {
-        qCWarning(LANGUAGE) << "Could not find a template archive for description" << templateDescription << ", archive file" << archiveFileName;
+        qCWarning(LANGUAGE) << "Could not find a template archive for description" << templateDescription <<
+            ", archive file" << archiveFileName;
         d->archive = nullptr;
     } else {
         QFileInfo info(archiveFileName);
@@ -205,11 +208,15 @@ void SourceFileTemplate::setTemplateDescription(const QString& templateDescripti
 
 bool SourceFileTemplate::isValid() const
 {
+    Q_D(const SourceFileTemplate);
+
     return d->archive;
 }
 
 QString SourceFileTemplate::name() const
 {
+    Q_D(const SourceFileTemplate);
+
     KConfig templateConfig(d->descriptionFileName);
     KConfigGroup cg(&templateConfig, "General");
     return cg.readEntry("Name");
@@ -217,6 +224,8 @@ QString SourceFileTemplate::name() const
 
 QString SourceFileTemplate::type() const
 {
+    Q_D(const SourceFileTemplate);
+
     KConfig templateConfig(d->descriptionFileName);
     KConfigGroup cg(&templateConfig, "General");
     return cg.readEntry("Type", QString());
@@ -224,6 +233,8 @@ QString SourceFileTemplate::type() const
 
 QString SourceFileTemplate::languageName() const
 {
+    Q_D(const SourceFileTemplate);
+
     KConfig templateConfig(d->descriptionFileName);
     KConfigGroup cg(&templateConfig, "General");
     return cg.readEntry("Language", QString());
@@ -231,6 +242,8 @@ QString SourceFileTemplate::languageName() const
 
 QStringList SourceFileTemplate::category() const
 {
+    Q_D(const SourceFileTemplate);
+
     KConfig templateConfig(d->descriptionFileName);
     KConfigGroup cg(&templateConfig, "General");
     return cg.readEntry("Category", QStringList());
@@ -238,6 +251,8 @@ QStringList SourceFileTemplate::category() const
 
 QStringList SourceFileTemplate::defaultBaseClasses() const
 {
+    Q_D(const SourceFileTemplate);
+
     KConfig templateConfig(d->descriptionFileName);
     KConfigGroup cg(&templateConfig, "General");
     return cg.readEntry("BaseClasses", QStringList());
@@ -245,12 +260,16 @@ QStringList SourceFileTemplate::defaultBaseClasses() const
 
 const KArchiveDirectory* SourceFileTemplate::directory() const
 {
+    Q_D(const SourceFileTemplate);
+
     Q_ASSERT(isValid());
     return d->archive->directory();
 }
 
 QVector<SourceFileTemplate::OutputFile> SourceFileTemplate::outputFiles() const
 {
+    Q_D(const SourceFileTemplate);
+
     QVector<SourceFileTemplate::OutputFile> outputFiles;
 
     KConfig templateConfig(d->descriptionFileName);
@@ -275,6 +294,8 @@ QVector<SourceFileTemplate::OutputFile> SourceFileTemplate::outputFiles() const
 
 bool SourceFileTemplate::hasCustomOptions() const
 {
+    Q_D(const SourceFileTemplate);
+
     Q_ASSERT(isValid());
 
     KConfig templateConfig(d->descriptionFileName);
@@ -287,6 +308,8 @@ bool SourceFileTemplate::hasCustomOptions() const
 
 QVector<SourceFileTemplate::ConfigOptionGroup> SourceFileTemplate::customOptions(TemplateRenderer* renderer) const
 {
+    Q_D(const SourceFileTemplate);
+
     Q_ASSERT(isValid());
 
     KConfig templateConfig(d->descriptionFileName);
@@ -295,11 +318,10 @@ QVector<SourceFileTemplate::ConfigOptionGroup> SourceFileTemplate::customOptions
 
     QVector<ConfigOptionGroup> optionGroups;
 
-    if (!entry->isFile())
-    {
+    if (!entry->isFile()) {
         return optionGroups;
     }
-    const KArchiveFile* file = static_cast<const KArchiveFile*>(entry);
+    const auto* file = static_cast<const KArchiveFile*>(entry);
 
     /*
      * Copied from kconfig_compiler.kcfg
@@ -308,41 +330,42 @@ QVector<SourceFileTemplate::ConfigOptionGroup> SourceFileTemplate::customOptions
     QString errorMsg;
     int errorRow;
     int errorCol;
-    if ( !doc.setContent( file->data(), &errorMsg, &errorRow, &errorCol ) ) {
+    if (!doc.setContent(file->data(), &errorMsg, &errorRow, &errorCol)) {
         qCDebug(LANGUAGE) << "Unable to load document.";
         qCDebug(LANGUAGE) << "Parse error in line " << errorRow << ", col " << errorCol << ": " << errorMsg;
         return optionGroups;
     }
 
     QDomElement cfgElement = doc.documentElement();
-    if ( cfgElement.isNull() ) {
+    if (cfgElement.isNull()) {
         qCDebug(LANGUAGE) << "No document in kcfg file";
         return optionGroups;
     }
 
     QDomNodeList groups = cfgElement.elementsByTagName(QStringLiteral("group"));
     optionGroups.reserve(groups.size());
-    for (int i = 0; i < groups.size(); ++i)
-    {
+    for (int i = 0; i < groups.size(); ++i) {
         QDomElement group = groups.at(i).toElement();
         ConfigOptionGroup optionGroup;
         optionGroup.name = group.attribute(QStringLiteral("name"));
 
         QDomNodeList entries = group.elementsByTagName(QStringLiteral("entry"));
         optionGroup.options.reserve(entries.size());
-        for (int j = 0; j < entries.size(); ++j)
-        {
+        for (int j = 0; j < entries.size(); ++j) {
             QDomElement entry = entries.at(j).toElement();
             optionGroup.options << d->readEntry(entry, renderer);
         }
 
         optionGroups << optionGroup;
     }
+
     return optionGroups;
 }
 
 void SourceFileTemplate::addAdditionalSearchLocation(const QString& location)
 {
-    if(!d->searchLocations.contains(location))
+    Q_D(SourceFileTemplate);
+
+    if (!d->searchLocations.contains(location))
         d->searchLocations.append(location);
 }
