@@ -208,7 +208,7 @@ void TestProjectModel::testChangeWithProxyModel()
 {
     QString projectFolderPath = QDir::rootPath() + QStringLiteral("folder1");
     QString projectFilePath = QDir::rootPath() + QStringLiteral("folder1/file1");
-    QSortFilterProxyModel* proxy = new QSortFilterProxyModel( this );
+    auto* proxy = new QSortFilterProxyModel( this );
     proxy->setSourceModel( model );
     ProjectFolderItem* root = new ProjectFolderItem( nullptr, Path(QUrl::fromLocalFile(projectFolderPath)) );
     root->appendRow( new ProjectFileItem( nullptr, Path(QUrl::fromLocalFile(projectFilePath)) ) );
@@ -231,9 +231,9 @@ void TestProjectModel::testCreateSimpleHierarchy()
     QString cppFileName = QStringLiteral("file.cpp");
     ProjectFolderItem* rootFolder = new ProjectFolderItem( nullptr, Path(QUrl::fromLocalFile( QDir::rootPath() + folderName )) );
     QCOMPARE(rootFolder->baseName(), folderName);
-    ProjectFileItem* file = new ProjectFileItem( fileName, rootFolder );
+    auto* file = new ProjectFileItem( fileName, rootFolder );
     QCOMPARE(file->baseName(), fileName);
-    ProjectTargetItem* target = new ProjectTargetItem( nullptr, targetName );
+    auto* target = new ProjectTargetItem( nullptr, targetName );
     rootFolder->appendRow( target );
     ProjectFileItem* targetfile = new ProjectFileItem( nullptr, Path(rootFolder->path(), cppFileName), target );
 
@@ -347,7 +347,7 @@ void TestProjectModel::testRename()
 
     const Path projectFolder = Path(QUrl::fromLocalFile(projectFolderPath));
     QScopedPointer<TestProject> proj(new TestProject());
-    ProjectFolderItem* rootItem = new ProjectFolderItem( proj.data(), projectFolder, nullptr);
+    auto* rootItem = new ProjectFolderItem( proj.data(), projectFolder, nullptr);
     proj->setProjectItem( rootItem );
 
     new ProjectFileItem(QStringLiteral("existing"), rootItem);
@@ -479,9 +479,9 @@ void TestProjectModel::testItemsForPath()
 
     model->appendRow(root);
 
-    auto items = model->itemsForPath(IndexedString(path.pathOrUrl()));
+    const auto items = model->itemsForPath(IndexedString(path.pathOrUrl()));
     QCOMPARE(items.size(), matches);
-    foreach(ProjectBaseItem* item, items) {
+    for (ProjectBaseItem* item : items) {
         QVERIFY(item->path() == path);
     }
 
@@ -537,7 +537,7 @@ void TestProjectModel::testProjectFileSet()
 
     QVERIFY(project->fileSet().isEmpty());
     Path path(QUrl::fromLocalFile(QDir::tempPath() + "/a"));
-    ProjectFileItem* item = new ProjectFileItem(project.data(), path, project->projectItem());
+    auto* item = new ProjectFileItem(project.data(), path, project->projectItem());
     QCOMPARE(project->fileSet().size(), 1);
     qDebug() << path << project->fileSet().toList().at(0).toUrl();
     QCOMPARE(Path(project->fileSet().toList().at(0).toUrl()), path);
