@@ -53,7 +53,7 @@ void BzrAnnotateJob::start()
 {
     if (m_status != KDevelop::VcsJob::JobNotStarted)
         return;
-    DVcsJob* job = new KDevelop::DVcsJob(m_workingDir, m_vcsPlugin, KDevelop::OutputJob::Silent);
+    auto* job = new KDevelop::DVcsJob(m_workingDir, m_vcsPlugin, KDevelop::OutputJob::Silent);
     *job << "bzr" << "annotate" << "--all" << m_revisionSpec << m_localLocation;
     connect(job, &DVcsJob::readyForParsing, this, &BzrAnnotateJob::parseBzrAnnotateOutput);
     m_status = VcsJob::JobRunning;
@@ -114,7 +114,7 @@ void BzrAnnotateJob::prepareCommitInfo(std::size_t revision)
 {
     if (m_status != KDevelop::VcsJob::JobRunning)
         return;
-    KDevelop::DVcsJob* job = new KDevelop::DVcsJob(m_workingDir, m_vcsPlugin, KDevelop::OutputJob::Silent);
+    auto* job = new KDevelop::DVcsJob(m_workingDir, m_vcsPlugin, KDevelop::OutputJob::Silent);
     job->setType(KDevelop::VcsJob::Log);
     *job << "bzr" << "log" << "--long" << "-r" << QString::number(revision);
     connect(job, &DVcsJob::readyForParsing, this, &BzrAnnotateJob::parseBzrLog);
@@ -145,9 +145,9 @@ void BzrAnnotateJob::parseBzrLog(KDevelop::DVcsJob* job)
                 // "revno??". If that's all, then we recover matching only
                 // "revno" prefix and assuming placeholder of length 2 (": " or
                 // "??").
-                // The same below with exception of "commiter" which possibly
+                // The same below with exception of "committer" which possibly
                 // can have also some suffix which changes meaning like
-                // "commiter-some_property: "...
+                // "committer-some_property: "...
                 revno = revno.left(revno.indexOf(QLatin1Char(' ')));
                 revision = revno.toInt();
                 KDevelop::VcsRevision revision;
@@ -155,10 +155,10 @@ void BzrAnnotateJob::parseBzrLog(KDevelop::DVcsJob* job)
                 commitInfo.setRevision(revision);
             } else if (line.startsWith(QStringLiteral("committer: "))) {
                 QString commiter = line.mid(QStringLiteral("committer: ").length());
-                commitInfo.setAuthor(commiter);     // Author goes after commiter, but only if is different
+                commitInfo.setAuthor(commiter);     // Author goes after committer, but only if is different
             } else if (line.startsWith(QStringLiteral("author"))) {
                 QString author = line.mid(QStringLiteral("author: ").length());
-                commitInfo.setAuthor(author);       // It may override commiter (In fact commiter is not supported by VcsEvent)
+                commitInfo.setAuthor(author);       // It may override committer (In fact committer is not supported by VcsEvent)
             } else if (line.startsWith(QStringLiteral("timestamp"))) {
                 const QString formatString = QStringLiteral("yyyy-MM-dd hh:mm:ss");
                 QString timestamp = line.mid(QStringLiteral("timestamp: ddd ").length(), formatString.length());
