@@ -103,8 +103,9 @@ FuncOverrideInfo processCXXMethod(CXCursor cursor, OverrideInfo* info)
         CXCursor arg = clang_Cursor_getArgument(cursor, i);
         QString id = ClangString(clang_getCursorDisplayName(arg)).toString();
         QString type = ClangString(clang_getTypeSpelling(clang_getCursorType(arg))).toString();
-        if (info->templateTypeMap.contains(type)) {
-            type = info->templateTypeMap.value(type);
+        const auto templateTypeIt = info->templateTypeMap.constFind(type);
+        if (templateTypeIt != info->templateTypeMap.constEnd()) {
+            type = *templateTypeIt;
         }
         FuncParameterInfo param;
         param.type = type;
@@ -114,8 +115,9 @@ FuncOverrideInfo processCXXMethod(CXCursor cursor, OverrideInfo* info)
 
     FuncOverrideInfo fp;
     QString retType = ClangString(clang_getTypeSpelling(clang_getCursorResultType(cursor))).toString();
-    if (info->templateTypeMap.contains(retType)) {
-        retType = info->templateTypeMap.value(retType);
+    const auto templateTypeIt = info->templateTypeMap.constFind(retType);
+    if (templateTypeIt != info->templateTypeMap.constEnd()) {
+        retType = *templateTypeIt;
     }
 
     fp.returnType = retType;
@@ -151,7 +153,7 @@ void processBaseClass(CXCursor cursor, CXCursor parent, FunctionOverrideList* fu
 CXChildVisitResult baseClassVisitor(CXCursor cursor, CXCursor parent, CXClientData data)
 {
     QString templateParam;
-    OverrideInfo* info = static_cast<OverrideInfo*>(data);
+    auto* info = static_cast<OverrideInfo*>(data);
 
     switch(clang_getCursorKind(cursor)) {
     case CXCursor_TemplateTypeParameter:
@@ -231,7 +233,7 @@ bool isQtMocFunction(CXCursor cursor)
 CXChildVisitResult declVisitor(CXCursor cursor, CXCursor parent, CXClientData d)
 {
     CXCursorKind kind = clang_getCursorKind(cursor);
-    struct ImplementsInfo* data = static_cast<struct ImplementsInfo*>(d);
+    auto* data = static_cast<struct ImplementsInfo*>(d);
 
     auto location = clang_getCursorLocation(cursor);
     if (clang_Location_isInSystemHeader(location)) {
