@@ -44,10 +44,10 @@ QString MacroNavigationContext::name() const
 
 QString MacroNavigationContext::html(bool shorten)
 {
+    Q_UNUSED(shorten);
     clear();
 
-    modifyHtml() += QLatin1String("<html><body><p>") + fontSizePrefix(shorten);
-    addExternalHtml(prefix());
+    modifyHtml() += QLatin1String("<html><body><p>");
 
     QStringList parameterList;
     parameterList.reserve(m_macro->parametersSize());
@@ -79,7 +79,7 @@ QString MacroNavigationContext::html(bool shorten)
     modifyHtml() += QLatin1String("<tt>") + code.toHtmlEscaped().replace(QLatin1Char('\n'), QStringLiteral("<br/>")) + QLatin1String("</tt>");
     modifyHtml() += QStringLiteral("</p>");
 
-    modifyHtml() += fontSizeSuffix(shorten) + QLatin1String("</p></body></html>");
+    modifyHtml() += QLatin1String("</p></body></html>");
     return currentHtml();
 }
 
