@@ -51,7 +51,7 @@ static QPointer<CustomScriptPlugin> indentPluginSingleton;
 K_PLUGIN_FACTORY_WITH_JSON(CustomScriptFactory, "kdevcustomscript.json", registerPlugin<CustomScriptPlugin>(); )
 
 // Replaces ${KEY} in command with variables[KEY]
-static QString replaceVariables(QString command, QMap<QString, QString> variables)
+static QString replaceVariables(QString command, const QMap<QString, QString>& variables)
 {
     while (command.contains(QLatin1String("${"))) {
         int pos = command.indexOf(QLatin1String("${"));
@@ -61,8 +61,9 @@ static QString replaceVariables(QString command, QMap<QString, QString> variable
         }
         QString key = command.mid(pos + 2, end - pos - 2);
 
-        if (variables.contains(key)) {
-            command.replace(pos, 1 + end - pos, variables[key]);
+        const auto variableIt = variables.constFind(key);
+        if (variableIt != variables.constEnd()) {
+            command.replace(pos, 1 + end - pos, *variableIt );
         } else {
             qCDebug(CUSTOMSCRIPT) << "found no variable while replacing in shell-command" << command << "key" << key << "available:" << variables;
             command.remove(pos, 1 + end - pos);
@@ -123,7 +124,8 @@ QString CustomScriptPlugin::formatSourceWithStyle(SourceFormatterStyle style, co
     useText = leftContext + useText + rightContext;
 
     QMap<QString, QString> projectVariables;
-    foreach (IProject* project, ICore::self()->projectController()->projects()) {
+    const auto projects = ICore::self()->projectController()->projects();
+    for (IProject* project : projects) {
         projectVariables[project->name()] = project->path().toUrl().toLocalFile();
     }
 
@@ -211,7 +213,8 @@ QString CustomScriptPlugin::formatSource(const QString& text, const QUrl& url, c
 static QVector<SourceFormatterStyle> stylesFromLanguagePlugins()
 {
     QVector<KDevelop::SourceFormatterStyle> styles;
-    foreach (auto lang, ICore::self()->languageController()->loadedLanguages()) {
+    const auto loadedLanguages = ICore::self()->languageController()->loadedLanguages();
+    for (auto* lang : loadedLanguages) {
         const SourceFormatterItemList& languageStyles = lang->sourceFormatterItems();
         for (const SourceFormatterStyleItem& item: languageStyles) {
             if (item.engine == QLatin1String("customscript")) {
@@ -246,6 +249,15 @@ KDevelop::SourceFormatterStyle CustomScriptPlugin::predefinedStyle(const QString
         result.setCaption(i18n("Gnu Indent: Original Berkeley indent style"));
         result.setContent(QStringLiteral("indent -orig"));
         result.setUsePreview(true);
+    } else if (name == QLatin1String("clang_format")) {
+        result.setCaption(i18n("Clang Format"));
+        result.setContent(QStringLiteral("clang-format -assume-filename=\"$FILE\""));
+        result.setUsePreview(false);
+        result.setDescription(i18n("Description:<br /><br />"
+                                   "<b>clang-format</b> is an automatic source formater by the LLVM "
+                                   "project. It supports a variety of formatting style options via "
+                                   "a <b>.clang-format</b> configuration file, usually located in "
+                                   "the project root directory."));
     } else if (name == QLatin1String("kdev_format_source")) {
         result.setCaption(QStringLiteral("KDevelop: kdev_format_source"));
         result.setContent(QStringLiteral("kdev_format_source $FILE $TMPFILE"));
@@ -285,6 +297,7 @@ QVector<KDevelop::SourceFormatterStyle> CustomScriptPlugin::predefinedStyles() c
 {
     const QVector<KDevelop::SourceFormatterStyle> styles = stylesFromLanguagePlugins() + QVector<KDevelop::SourceFormatterStyle>{
         predefinedStyle(QStringLiteral("kdev_format_source")),
+        predefinedStyle(QStringLiteral("clang_format")),
         predefinedStyle(QStringLiteral("GNU_indent_GNU")),
         predefinedStyle(QStringLiteral("GNU_indent_KR")),
         predefinedStyle(QStringLiteral("GNU_indent_orig")),
@@ -523,7 +536,7 @@ CustomScriptPreferences::CustomScriptPreferences()
              "If you add <b>$TMPFILE</b> into the command, then <br />"
              "a temporary file is used for transferring the code."));
     connect(m_commandEdit, &QLineEdit::textEdited,
-            m_updateTimer, static_cast<void (QTimer::*)()>(&QTimer::start));
+            m_updateTimer, QOverload<>::of(&QTimer::start));
 
     m_vLayout->addSpacing(10);
 
@@ -566,5 +579,3 @@ void CustomScriptPreferences::moreVariablesClicked(bool)
 }
 
 #include "customscript_plugin.moc"
-
-// kate: indent-mode cstyle; space-indent off; tab-width 4;
