@@ -42,9 +42,10 @@ class KDevDocumentViewPluginFactory: public KDevelop::IToolViewFactory
         {}
         QWidget* create( QWidget *parent = nullptr ) override
         {
-            KDevDocumentView* view = new KDevDocumentView( m_plugin, parent );
+            auto* view = new KDevDocumentView( m_plugin, parent );
             KDevelop::IDocumentController* docController = m_plugin->core()->documentController();
-            foreach(KDevelop::IDocument* doc, docController->openDocuments()) {
+            const auto openDocuments = docController->openDocuments();
+            for (KDevelop::IDocument* doc : openDocuments) {
                 view->opened( doc );
             }
             QObject::connect( docController, &IDocumentController::documentActivated,
