@@ -94,9 +94,9 @@ inline QStringList repl_template()
 inline QStringList filepatterns()
 {
     return QStringList{
-        QStringLiteral("*.h,*.hxx,*.hpp,*.hh,*.h++,*.H,*.tlh,*.cpp,*.cc,*.C,*.c++,*.cxx,*.ocl,*.inl,*.idl,*.c,*.m,*.mm,*.M,*.y,*.ypp,*.yxx,*.y++,*.l"),
-        QStringLiteral("*.cpp,*.cc,*.C,*.c++,*.cxx,*.ocl,*.inl,*.c,*.m,*.mm,*.M"),
-        QStringLiteral("*.h,*.hxx,*.hpp,*.hh,*.h++,*.H,*.tlh,*.idl"),
+        QStringLiteral("*.h,*.hxx,*.hpp,*.hh,*.h++,*.H,*.tlh,*.cuh,*.cpp,*.cc,*.C,*.c++,*.cxx,*.ocl,*.inl,*.idl,*.c,*.cu,*.m,*.mm,*.M,*.y,*.ypp,*.yxx,*.y++,*.l,*.txt,*.xml,*.rc"),
+        QStringLiteral("*.cpp,*.cc,*.C,*.c++,*.cxx,*.ocl,*.inl,*.c,*.cu,*.m,*.mm,*.M"),
+        QStringLiteral("*.h,*.hxx,*.hpp,*.hh,*.h++,*.H,*.tlh,*.cuh,*.idl"),
         QStringLiteral("*.adb"),
         QStringLiteral("*.cs"),
         QStringLiteral("*.f"),
@@ -160,14 +160,11 @@ QList<QUrl> getDirectoryChoice(const QString& text)
 ///Check if all directories are part of a project
 bool directoriesInProject(const QString& dir)
 {
-    foreach (const QUrl& url, getDirectoryChoice(dir)) {
+    const auto urls = getDirectoryChoice(dir);
+    return std::all_of(urls.begin(), urls.end(), [&](const QUrl& url) {
         IProject *proj = ICore::self()->projectController()->findProjectForUrl(url);
-        if (!proj || !proj->path().toUrl().isLocalFile()) {
-           return false;
-        }
-    }
-
-    return true;
+        return (proj && proj->path().toUrl().isLocalFile());
+    });
 }
 
 ///Max number of items in paths combo box.
@@ -200,6 +197,7 @@ GrepDialog::GrepDialog(GrepViewPlugin *plugin, QWidget *parent, bool show)
 
     patternCombo->addItems( cg.readEntry("LastSearchItems", QStringList()) );
     patternCombo->setInsertPolicy(QComboBox::InsertAtTop);
+    patternCombo->setCompleter(nullptr);
 
     templateTypeCombo->addItems(template_desc());
     templateTypeCombo->setCurrentIndex( cg.readEntry("LastUsedTemplateIndex", 0) );
@@ -207,14 +205,16 @@ GrepDialog::GrepDialog(GrepViewPlugin *plugin, QWidget *parent, bool show)
     templateEdit->setEditable(true);
     templateEdit->setCompletionMode(KCompletion::CompletionPopup);
     KCompletion* comp = templateEdit->completionObject();
-    connect(templateEdit, static_cast<void(KComboBox::*)(const QString&)>(&KComboBox::returnPressed), comp, static_cast<void(KCompletion::*)(const QString&)>(&KCompletion::addItem));
+    connect(templateEdit, QOverload<const QString&>::of(&KComboBox::returnPressed),
+            comp, QOverload<const QString&>::of(&KCompletion::addItem));
     for(int i=0; i<templateEdit->count(); i++)
         comp->addItem(templateEdit->itemText(i));
     replacementTemplateEdit->addItems( cg.readEntry("LastUsedReplacementTemplateString", repl_template()) );
     replacementTemplateEdit->setEditable(true);
     replacementTemplateEdit->setCompletionMode(KCompletion::CompletionPopup);
     comp = replacementTemplateEdit->completionObject();
-    connect(replacementTemplateEdit, static_cast<void(KComboBox::*)(const QString&)>(&KComboBox::returnPressed), comp, static_cast<void(KCompletion::*)(const QString&)>(&KCompletion::addItem));
+    connect(replacementTemplateEdit, QOverload<const QString&>::of(&KComboBox::returnPressed),
+            comp, QOverload<const QString&>::of(&KCompletion::addItem));
     for(int i=0; i<replacementTemplateEdit->count(); i++)
         comp->addItem(replacementTemplateEdit->itemText(i));
 
@@ -239,14 +239,15 @@ GrepDialog::GrepDialog(GrepViewPlugin *plugin, QWidget *parent, bool show)
     filesCombo->addItems(cg.readEntry("file_patterns", filepatterns()));
     excludeCombo->addItems(cg.readEntry("exclude_patterns", excludepatterns()) );
 
-    connect(templateTypeCombo, static_cast<void(KComboBox::*)(int)>(&KComboBox::activated),
+    connect(templateTypeCombo, QOverload<int>::of(&KComboBox::activated),
             this, &GrepDialog::templateTypeComboActivated);
     connect(patternCombo, &QComboBox::editTextChanged,
             this, &GrepDialog::patternComboEditTextChanged);
     patternComboEditTextChanged( patternCombo->currentText() );
     patternCombo->setFocus();
 
-    connect(searchPaths, static_cast<void(KComboBox::*)(const QString&)>(&KComboBox::activated), this, &GrepDialog::setSearchLocations);
+    connect(searchPaths, QOverload<const QString&>::of(&KComboBox::activated),
+            this, &GrepDialog::setSearchLocations);
 
     directorySelector->setIcon(QIcon::fromTheme(QStringLiteral("document-open")));
     connect(directorySelector, &QPushButton::clicked, this, &GrepDialog::selectDirectoryDialog );
@@ -278,14 +279,14 @@ void GrepDialog::addStringToMenu(QMenu* menu, const QString& string)
 
 void GrepDialog::synchronizeDirActionTriggered(bool)
 {
-    QAction* action = qobject_cast<QAction*>(sender());
+    auto* action = qobject_cast<QAction*>(sender());
     Q_ASSERT(action);
     setSearchLocations(action->data().toString());
 }
 
 QMenu* GrepDialog::createSyncButtonMenu()
 {
-    QMenu* ret = new QMenu(this);
+    auto* ret = new QMenu(this);
 
     QSet<Path> hadUrls;
 
@@ -311,8 +312,8 @@ QMenu* GrepDialog::createSyncButtonMenu()
     }
 
     QVector<QUrl> otherProjectUrls;
-    foreach(IProject* project, m_plugin->core()->projectController()->projects())
-    {
+    const auto projects = m_plugin->core()->projectController()->projects();
+    for (IProject* project : projects) {
         if (!hadUrls.contains(project->path())) {
             otherProjectUrls.append(project->path().toUrl());
         }
@@ -320,8 +321,7 @@ QMenu* GrepDialog::createSyncButtonMenu()
 
     // sort the remaining project URLs alphabetically
     std::sort(otherProjectUrls.begin(), otherProjectUrls.end());
-    foreach(const QUrl& url, otherProjectUrls)
-    {
+    for (const QUrl& url : qAsConst(otherProjectUrls)) {
         addUrlToMenu(ret, url);
     }
 
@@ -439,7 +439,8 @@ bool GrepDialog::checkProjectsOpened()
         KDevelop::ICore::self()->projectController()->projects().count())
         return false;
 
-    foreach (IProject* p, KDevelop::ICore::self()->projectController()->projects()) {
+    const auto projects = KDevelop::ICore::self()->projectController()->projects();
+    for (IProject* p : projects) {
         if (!p->isReady())
             return false;
     }
@@ -463,7 +464,8 @@ void GrepDialog::nextHistory(bool next)
 
 bool GrepDialog::isPartOfChoice(const QUrl& url) const
 {
-    foreach(const QUrl& choice, getDirectoryChoice(m_settings.searchPaths)) {
+    const auto choices = getDirectoryChoice(m_settings.searchPaths);
+    for (const QUrl& choice : choices) {
         if(choice.isParentOf(url) || choice == url)
             return true;
     }
@@ -481,8 +483,8 @@ void GrepDialog::startSearch()
 
     // search for unsaved documents
     QList<IDocument*> unsavedFiles;
-    foreach(IDocument* doc, ICore::self()->documentController()->openDocuments())
-    {
+    const auto documents = ICore::self()->documentController()->openDocuments();
+    for (IDocument* doc : documents) {
         QUrl docUrl = doc->url();
         if (doc->state() != IDocument::Clean &&
             isPartOfChoice(docUrl) &&
