@@ -38,7 +38,6 @@
 #include <interfaces/idebugcontroller.h>
 #include <interfaces/ilaunchconfiguration.h>
 #include <util/environmentprofilelist.h>
-#include <qtcompat_p.h>
 
 #include <KConfigGroup>
 #include <KLocalizedString>
@@ -243,7 +242,8 @@ void DebugSession::configInferior(ILaunchConfiguration *cfg, IExecutePlugin *iex
     if (breakOnStart) {
         BreakpointModel* m = ICore::self()->debugController()->breakpointModel();
         bool found = false;
-        foreach (Breakpoint *b, m->breakpoints()) {
+        const auto breakpoints = m->breakpoints();
+        for (Breakpoint* b : breakpoints) {
             if (b->location() == QLatin1String("main")) {
                 found = true;
                 break;
@@ -337,7 +337,7 @@ void DebugSession::ensureDebuggerListening()
     // no need to interrupt
     setDebuggerStateOff(s_dbgNotListening);
     // NOTE: there is actually a bug in lldb-mi that, when receiving SIGINT,
-    // it would print '^done', which doesn't coresponds to any previous command.
+    // it would print '^done', which doesn't corresponds to any previous command.
     // This confuses our command queue.
 }
 
@@ -473,7 +473,7 @@ void DebugSession::updateAllVariables()
     // variables.
     QList<LldbVariable*> toplevels;
     for (auto it = m_allVariables.begin(), ite = m_allVariables.end(); it != ite; ++it) {
-        LldbVariable *var = qobject_cast<LldbVariable*>(it.value());
+        auto *var = qobject_cast<LldbVariable*>(it.value());
         if (var->topLevel()) {
             toplevels << var;
         }
@@ -489,7 +489,7 @@ void DebugSession::handleSessionStateChange(IDebugSession::DebuggerState state)
     if (state == IDebugSession::PausedState) {
         // session is paused, the user can input any commands now.
         // Turn off delete duplicate breakpoints mode, as the user
-        // may intentionaly want to do this.
+        // may intentionally want to do this.
         qCDebug(DEBUGGERLLDB) << "Turn off delete duplicate mode";
         breakpointController()->setDeleteDuplicateBreakpoints(false);
     }
