@@ -19,8 +19,6 @@
 #include "ui/perforceimportmetadatawidget.h"
 #include "debug.h"
 
-#include "qtcompat_p.h"
-
 #include <KLocalizedString>
 #include <QFileInfo>
 #include <QDateTime>
@@ -309,7 +307,7 @@ KDevelop::VcsJob* PerforcePlugin::diff(const QUrl& fileOrDirectory, const KDevel
     QFileInfo curFile(fileOrDirectory.toLocalFile());
     QString depotSrcFileName = getRepositoryName(curFile);
     QString depotDstFileName = depotSrcFileName;
-    depotSrcFileName.append(toRevisionName(srcRevision, dstRevision.prettyValue())); // dstRevision acutally contains the number that we want to take previous of
+    depotSrcFileName.append(toRevisionName(srcRevision, dstRevision.prettyValue())); // dstRevision actually contains the number that we want to take previous of
 
     DVcsJob* job = new DVcsJob(curFile.dir(), this, KDevelop::OutputJob::Verbose);
     setEnvironmentForJob(job, curFile);
@@ -329,6 +327,7 @@ KDevelop::VcsJob* PerforcePlugin::diff(const QUrl& fileOrDirectory, const KDevel
         default:
             break;
         }
+        break;
     default:
         break;
     }
@@ -631,7 +630,7 @@ void PerforcePlugin::parseP4AnnotateOutput(DVcsJob *job)
     
     VcsEvent item;
     QMap<qlonglong, VcsEvent> globalCommits;
-    /// Move the VcsEvents to a more suitable data strucure
+    /// Move the VcsEvents to a more suitable data structure
     for (QList<QVariant>::const_iterator commitsIt = commits.constBegin(), commitsEnd = commits.constEnd(); 
            commitsIt != commitsEnd; ++commitsIt) {
         if(commitsIt->canConvert<VcsEvent>())
