@@ -148,7 +148,7 @@ ProjectBaseItem* ProjectTreeView::itemAtPos(const QPoint& pos) const
 
 void ProjectTreeView::dropEvent(QDropEvent* event)
 {
-    ProjectItemContext* selectionCtxt =
+    auto* selectionCtxt =
             static_cast<ProjectItemContext*>(KDevelop::ICore::self()->selectionController()->currentSelection());
     ProjectBaseItem* destItem = itemAtPos(event->pos());
     if (destItem && (dropIndicatorPosition() == AboveItem || dropIndicatorPosition() == BelowItem))
@@ -192,7 +192,7 @@ void ProjectTreeView::dropEvent(QDropEvent* event)
             filterDroppedItems(usefulItems, destItem);
             Path::List paths;
             paths.reserve(usefulItems.size());
-            foreach (ProjectBaseItem* i, usefulItems) {
+            for (ProjectBaseItem* i : qAsConst(usefulItems)) {
                 paths << i->path();
             }
             bool success = false;
@@ -208,9 +208,10 @@ void ProjectTreeView::dropEvent(QDropEvent* event)
 
                 //and select new items
                 QItemSelection selection;
-                foreach (const Path &path, paths) {
+                for (const Path& path : qAsConst(paths)) {
                     const Path targetPath(folder->path(), path.lastPathSegment());
-                    foreach (ProjectBaseItem *item, folder->children()) {
+                    const auto folderChildren = folder->children();
+                    for (ProjectBaseItem* item : folderChildren) {
                         if (item->path() == targetPath) {
                             QModelIndex indx = mapFromItem( item );
                             selection.append(QItemSelectionRange(indx, indx));
@@ -262,7 +263,7 @@ QModelIndex ProjectTreeView::mapFromSource(const QAbstractProxyModel* proxy, con
     if(next == sourceIdx.model())
         return proxy->mapFromSource(sourceIdx);
     else {
-        const QAbstractProxyModel* nextProxy = qobject_cast<const QAbstractProxyModel*>(next);
+        const auto* nextProxy = qobject_cast<const QAbstractProxyModel*>(next);
         QModelIndex idx = mapFromSource(nextProxy, sourceIdx);
         Q_ASSERT(idx.model() == nextProxy);
         return proxy->mapFromSource(idx);
@@ -282,7 +283,7 @@ void ProjectTreeView::slotActivated( const QModelIndex &index )
         // Do not open file when Ctrl or Shift is pressed; that's for selection
         return;
     }
-    KDevelop::ProjectBaseItem *item = index.data(ProjectModel::ProjectItemRole).value<ProjectBaseItem*>();
+    auto *item = index.data(ProjectModel::ProjectItemRole).value<ProjectBaseItem*>();
     if ( item && item->file() )
     {
         emit activate( item->file()->path() );
@@ -302,7 +303,7 @@ QList<ProjectBaseItem*> ProjectTreeView::selectedProjects()
     if ( selectionModel()->hasSelection() ) {
         QModelIndexList indexes = selectionModel()->selectedRows();
         for ( const QModelIndex& index: indexes ) {
-            ProjectBaseItem* item = index.data( ProjectModel::ProjectItemRole ).value<ProjectBaseItem*>();
+            auto* item = index.data( ProjectModel::ProjectItemRole ).value<ProjectBaseItem*>();
             if ( item ) {
                 itemlist << item;
                 m_previousSelection = item->project();
@@ -359,8 +360,7 @@ void ProjectTreeView::popupContextMenu( const QPoint &pos )
     {
         QMenu* analyzeMenu = new QMenu(i18n("Analyze With"), &menu);
         analyzeMenu->setIcon(QIcon::fromTheme(QStringLiteral("dialog-ok")));
-        foreach( QAction* act, analyzeActions )
-        {
+        for (QAction* act : qAsConst(analyzeActions)) {
             analyzeMenu->addAction( act );
         }
         analyzeActions = {analyzeMenu->menuAction()};
