@@ -65,7 +65,7 @@ public:
 
     QString id() const override
     {
-        return QStringLiteral("org.kdevelop.scratchpad");
+        return QStringLiteral("org.kdevelop.ScratchpadView");
     }
 
 private:
@@ -207,7 +207,7 @@ void Scratchpad::renameScratch(const QModelIndex& index, const QString& previous
     const QString newName = index.data().toString();
     if (newName.contains(QDir::separator())) {
         m_model->setData(index, previousName); // undo
-        emit actionFailed(i18n("Failed to rename scratch: Names must not include path seperator"));
+        emit actionFailed(i18n("Failed to rename scratch: Names must not include path separator"));
         return;
     }
 
