@@ -73,12 +73,16 @@ StandardOutputView::StandardOutputView(QObject *parent, const QVariantList &)
 
 void StandardOutputView::removeSublimeView( Sublime::View* v )
 {
-    foreach (ToolViewData* d, m_toolViews) {
+    auto it = m_toolViews.begin();
+    while (it != m_toolViews.end()) {
+        ToolViewData* d = it.value();
+        bool isErased = false;
         if( d->views.contains(v) )
         {
             if( d->views.count() == 1 )
             {
-                m_toolViews.remove(d->toolViewId);
+                isErased = true;
+                it = m_toolViews.erase(it);
                 m_ids.removeAll( d->toolViewId );
                 delete d;
             } else
@@ -86,6 +90,9 @@ void StandardOutputView::removeSublimeView( Sublime::View* v )
                 d->views.removeAll(v);
             }
         }
+        if (!isErased) {
+            ++it;
+        }
     }
 }
 
@@ -95,10 +102,11 @@ StandardOutputView::~StandardOutputView()
 
 int StandardOutputView::standardToolView( KDevelop::IOutputView::StandardToolView view )
 {
-    if( m_standardViews.contains( view ) )
-    {
-        return m_standardViews.value( view );
+    const auto standardViewIt = m_standardViews.constFind(view);
+    if (standardViewIt != m_standardViews.constEnd()) {
+        return *standardViewIt;
     }
+
     int ret = -1;
     switch( view )
     {
@@ -140,7 +148,7 @@ int StandardOutputView::registerToolView( const QString& title,
                                           const QList<QAction*>& actionList )
 {
     // try to reuse existing tool view
-    foreach (ToolViewData* d, m_toolViews) {
+    for (ToolViewData* d : qAsConst(m_toolViews)) {
         if ( d->type == type && d->title == title ) {
             return d->toolViewId;
         }
@@ -149,7 +157,7 @@ int StandardOutputView::registerToolView( const QString& title,
     // register new tool view
     const int newid = m_ids.isEmpty() ? 0 : (m_ids.last() + 1);
     qCDebug(PLUGIN_STANDARDOUTPUTVIEW) << "Registering view" << title << "with type:" << type << "id:" << newid;
-    ToolViewData* tvdata = new ToolViewData( this );
+    auto* tvdata = new ToolViewData( this );
     tvdata->toolViewId = newid;
     tvdata->type = type;
     tvdata->title = title;
@@ -167,7 +175,8 @@ int StandardOutputView::registerOutputInToolView( int toolViewId,
                                                   const QString& title,
                                                   KDevelop::IOutputView::Behaviours behaviour )
 {
-    if (!m_toolViews.contains(toolViewId))
+    const auto toolViewIt = m_toolViews.constFind(toolViewId);
+    if (toolViewIt == m_toolViews.constEnd())
         return -1;
     int newid;
     if( m_ids.isEmpty() )
@@ -178,81 +187,83 @@ int StandardOutputView::registerOutputInToolView( int toolViewId,
         newid = m_ids.last()+1;
     }
     m_ids << newid;
-    m_toolViews.value(toolViewId)->addOutput(newid, title, behaviour);
+    (*toolViewIt)->addOutput(newid, title, behaviour);
     return newid;
 }
 
 void StandardOutputView::raiseOutput(int outputId)
 {
-    foreach (int _id, m_toolViews.keys()) {
-        if (m_toolViews.value(_id)->outputdata.contains(outputId)) {
-            foreach (Sublime::View* v, m_toolViews.value(_id)->views) {
+    for (const auto* toolViewData : qAsConst(m_toolViews))  {
+        if (toolViewData->outputdata.contains(outputId)) {
+            for (Sublime::View* v : qAsConst(toolViewData->views)) {
                 if( v->hasWidget() )
                 {
-                    OutputWidget* w = qobject_cast<OutputWidget*>( v->widget() );
+                    auto* w = qobject_cast<OutputWidget*>( v->widget() );
                     w->raiseOutput( outputId );
                     v->requestRaise();
                 }
             }
         }
+        // TODO: not break here?
     }
 }
 
 void StandardOutputView::setModel( int outputId, QAbstractItemModel* model )
 {
-    int tvid = -1;
-    foreach (int _id, m_toolViews.keys()) {
-        if (m_toolViews.value( _id)->outputdata.contains(outputId)) {
-            tvid = _id;
+    OutputData* outputData = nullptr;
+    for (const auto* toolViewData : qAsConst(m_toolViews))  {
+        const auto& outputDataMap = toolViewData->outputdata;
+        auto outputDataIt = outputDataMap.find(outputId);
+        if (outputDataIt != outputDataMap.end()) {
+            outputData = outputDataIt.value();
             break;
         }
     }
-    if( tvid == -1 )
+    if (!outputData) {
         qCDebug(PLUGIN_STANDARDOUTPUTVIEW) << "Trying to set model on unknown view-id:" << outputId;
-    else
-    {
-        m_toolViews.value(tvid)->outputdata.value(outputId)->setModel(model);
+    } else {
+        outputData->setModel(model);
     }
 }
 
 void StandardOutputView::setDelegate( int outputId, QAbstractItemDelegate* delegate )
 {
-    int tvid = -1;
-    foreach (int _id, m_toolViews.keys()) {
-        if (m_toolViews.value(_id)->outputdata.contains(outputId)) {
-            tvid = _id;
+    OutputData* outputData = nullptr;
+    for (const auto* toolViewData : qAsConst(m_toolViews))  {
+        const auto& outputDataMap = toolViewData->outputdata;
+        auto outputDataIt = outputDataMap.find(outputId);
+        if (outputDataIt != outputDataMap.end()) {
+            outputData = outputDataIt.value();
             break;
         }
     }
-    if( tvid == -1 )
+    if (!outputData) {
         qCDebug(PLUGIN_STANDARDOUTPUTVIEW) << "Trying to set model on unknown view-id:" << outputId;
-    else
-    {
-        m_toolViews.value(tvid)->outputdata.value(outputId)->setDelegate(delegate);
+    } else {
+        outputData->setDelegate(delegate);
     }
 }
 
 void StandardOutputView::removeToolView(int toolViewId)
 {
-    if (m_toolViews.contains(toolViewId)) {
-        ToolViewData* td = m_toolViews.value(toolViewId);
-        foreach( Sublime::View* view, td->views )
-        {
+    const auto toolViewIt = m_toolViews.find(toolViewId);
+    if (toolViewIt != m_toolViews.end()) {
+        ToolViewData* td = *toolViewIt;
+        const auto views = td->views;
+        for (Sublime::View* view : views) {
             if( view->hasWidget() )
             {
-                OutputWidget* outputWidget = qobject_cast<OutputWidget*>( view->widget() );
-                foreach( int outid, td->outputdata.keys() )
-                {
-                    outputWidget->removeOutput( outid );
+                auto* outputWidget = qobject_cast<OutputWidget*>( view->widget() );
+                for (auto it = td->outputdata.keyBegin(), end = td->outputdata.keyEnd(); it != end; ++it) {
+                    outputWidget->removeOutput(*it);
                 }
             }
-            foreach( Sublime::Area* area, KDevelop::ICore::self()->uiController()->controller()->allAreas() )
-            {
+            for (Sublime::Area* area : KDevelop::ICore::self()->uiController()->controller()->allAreas()) {
                 area->removeToolView( view );
             }
         }
         delete td;
-        m_toolViews.remove(toolViewId);
+        m_toolViews.erase(toolViewIt);
         emit toolViewRemoved(toolViewId);
     }
 }
@@ -262,8 +273,7 @@ OutputWidget* StandardOutputView::outputWidgetForId( int outputId ) const
     for (ToolViewData* td : m_toolViews) {
         if( td->outputdata.contains( outputId ) )
         {
-            foreach( Sublime::View* view, td->views )
-            {
+            for (Sublime::View* view : qAsConst(td->views)) {
                 if( view->hasWidget() )
                     return qobject_cast<OutputWidget*>( view->widget() );
             }
@@ -281,15 +291,14 @@ void StandardOutputView::scrollOutputTo( int outputId, const QModelIndex& idx )
 
 void StandardOutputView::removeOutput( int outputId )
 {
-    foreach (ToolViewData* td, m_toolViews) {
-        if( td->outputdata.contains( outputId ) )
-        {
-            foreach( Sublime::View* view, td->views )
-            {
+    for (ToolViewData* td : qAsConst(m_toolViews)) {
+        const auto outputIt = td->outputdata.find(outputId);
+        if (outputIt != td->outputdata.end()) {
+            for (Sublime::View* view : qAsConst(td->views)) {
                 if( view->hasWidget() )
                     qobject_cast<OutputWidget*>( view->widget() )->removeOutput( outputId );
             }
-            td->outputdata.remove( outputId );
+            td->outputdata.erase(outputIt);
         }
     }
 }
